def is_power2(num):
    'states if a number is a power of two'
    return num != 0 and ((num & (num - 1)) == 0)

countries = [
    b'Afghanistan',
    b'Albania',
    b'Algeria',
    b'Andorra',
    b'Angola',
    b'Antigua & Deps',
    b'Argentina',
    b'Armenia',
    b'Australia',
    b'Austria',
    b'Azerbaijan',
    b'Bahamas',
    b'Bahrain',
    b'Bangladesh',
    b'Barbados',
    b'Belarus',
    b'Belgium',
    b'Belize',
    b'Benin',
    b'Bhutan',
    b'Bolivia',
    b'Bosnia Herzegovina',
    b'Botswana',
    b'Brazil',
    b'Brunei',
    b'Bulgaria',
    b'Burkina',
    b'Burundi',
    b'Cambodia',
    b'Cameroon',
    b'Canada',
    b'Cape Verde',
    b'Central African Rep',
    b'Chad',
    b'Chile',
    b'China',
    b'Colombia',
    b'Comoros',
    b'Congo',
    b'Congo',
    b'Costa Rica',
    b'Croatia',
    b'Cuba',
    b'Cyprus',
    b'Czech Republic',
    b'Denmark',
    b'Djibouti',
    b'Dominica',
    b'Dominican Republic',
    b'East Timor',
    b'Ecuador',
    b'Egypt',
    b'El Salvador',
    b'Equatorial Guinea',
    b'Eritrea',
    b'Estonia',
    b'Ethiopia',
    b'Fiji',
    b'Finland',
    b'France',
    b'Gabon',
    b'Gambia',
    b'Georgia',
    b'Germany',
    b'Ghana',
    b'Greece',
    b'Grenada',
    b'Guatemala',
    b'Guinea',
    b'Guinea-Bissau',
    b'Guyana',
    b'Haiti',
    b'Honduras',
    b'Hungary',
    b'Iceland',
    b'India',
    b'Indonesia',
    b'Iran',
    b'Iraq',
    b'Ireland',
    b'Israel',
    b'Italy',
    b'Ivory Coast',
    b'Jamaica',
    b'Japan',
    b'Jordan',
    b'Kazakhstan',
    b'Kenya',
    b'Kiribati',
    b'Korea North',
    b'Korea South',
    b'Kosovo',
    b'Kuwait',
    b'Kyrgyzstan',
    b'Laos',
    b'Latvia',
    b'Lebanon',
    b'Lesotho',
    b'Liberia',
    b'Libya',
    b'Liechtenstein',
    b'Lithuania',
    b'Luxembourg',
    b'Macedonia',
    b'Madagascar',
    b'Malawi',
    b'Malaysia',
    b'Maldives',
    b'Mali',
    b'Malta',
    b'Marshall Islands',
    b'Mauritania',
    b'Mauritius',
    b'Mexico',
    b'Micronesia',
    b'Moldova',
    b'Monaco',
    b'Mongolia',
    b'Montenegro',
    b'Morocco',
    b'Mozambique',
    b'Myanmar',
    b'Namibia',
    b'Nauru',
    b'Nepal',
    b'Netherlands',
    b'New Zealand',
    b'Nicaragua',
    b'Niger',
    b'Nigeria',
    b'Norway',
    b'Oman',
    b'Pakistan',
    b'Palau',
    b'Panama',
    b'Papua New Guinea',
    b'Paraguay',
    b'Peru',
    b'Philippines',
    b'Poland',
    b'Portugal',
    b'Qatar',
    b'Romania',
    b'Russian Federation',
    b'Rwanda',
    b'St Kitts & Nevis',
    b'St Lucia',
    b'Saint Vincent & the Grenadines',
    b'Samoa',
    b'San Marino',
    b'Sao Tome & Principe',
    b'Saudi Arabia',
    b'Senegal',
    b'Serbia',
    b'Seychelles',
    b'Sierra Leone',
    b'Singapore',
    b'Slovakia',
    b'Slovenia',
    b'Solomon Islands',
    b'Somalia',
    b'South Africa',
    b'South Sudan',
    b'Spain',
    b'Sri Lanka',
    b'Sudan',
    b'Suriname',
    b'Swaziland',
    b'Sweden',
    b'Switzerland',
    b'Syria',
    b'Taiwan',
    b'Tajikistan',
    b'Tanzania',
    b'Thailand',
    b'Togo',
    b'Tonga',
    b'Trinidad & Tobago',
    b'Tunisia',
    b'Turkey',
    b'Turkmenistan',
    b'Tuvalu',
    b'Uganda',
    b'Ukraine',
    b'United Arab Emirates',
    b'United Kingdom',
    b'United States',
    b'Uruguay',
    b'Uzbekistan',
    b'Vanuatu',
    b'Vatican City',
    b'Venezuela',
    b'Vietnam',
    b'Yemen',
    b'Zambia',
    b'Zimbabwe'
]
